==> ktp-accounts-kcm-15.12.3.tar.xz: ktp-accounts-kcm-15.12.3/plugins/sunshine/sunshine-advanced-options-widget.cpp <==
/*
 * This file is part of telepathy-accounts-kcm-plugins
 *
 * Copyright (C) 2011 Florian Reinhard <florian.reinhard@googlemail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "sunshine-advanced-options-widget.h"

#include <KCMTelepathyAccounts/ParameterEditModel>

SunshineAdvancedOptionsWidget::SunshineAdvancedOptionsWidget(ParameterEditModel* model, QWidget* parent)
    : AbstractAccountParametersWidget(model, parent)
{
    // Set up the UI.
    m_ui = new Ui::SunshineAdvancedOptionsWidget;
    m_ui->setupUi(this);

    handleParameter(QLatin1String("use-specified-server"), QVariant::Bool,
                    m_ui->serverGroupBox,
                    0);
    handleParameter(QLatin1String("server"), QVariant::String,
                    m_ui->serverLineEdit,
                    m_ui->serverLabel);
    handleParameter(QLatin1String("port"), QVariant::UInt,
                    m_ui->portSpinBox,
                    m_ui->portLabel);
    handleParameter(QLatin1String("use-ssl"), QVariant::Bool,
                    m_ui->sslCheckBox,
                    m_ui->sslLabel);
    handleParameter(QLatin1String("export-contacts"), QVariant::Bool,
                    m_ui->exportContactsCheckBox,
                    m_ui->exportContactsLabel);
}

SunshineAdvancedOptionsWidget::~SunshineAdvancedOptionsWidget()
{
    delete m_ui;
}

#include "sunshine-advanced-options-widget.moc"

==> ktp-accounts-kcm_20.08.0.orig.tar.xz: ktp-accounts-kcm-20.08.0/plugins/sunshine/sunshine-advanced-options-widget.cpp <==
/*
 * This file is part of telepathy-accounts-kcm-plugins
 *
 * Copyright (C) 2011 Florian Reinhard <florian.reinhard@googlemail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "sunshine-advanced-options-widget.h"

#include <KCMTelepathyAccounts/ParameterEditModel>

SunshineAdvancedOptionsWidget::SunshineAdvancedOptionsWidget(ParameterEditModel* model, QWidget* parent)
    : AbstractAccountParametersWidget(model, parent)
{
    // Set up the UI.
    m_ui = new Ui::SunshineAdvancedOptionsWidget;
    m_ui->setupUi(this);

    handleParameter(QLatin1String("use-specified-server"), QVariant::Bool,
                    m_ui->serverGroupBox);
    handleParameter(QLatin1String("server"), QVariant::String,
                    m_ui->serverLineEdit,
                    m_ui->serverLabel);
    handleParameter(QLatin1String("port"), QVariant::UInt,
                    m_ui->portSpinBox,
                    m_ui->portLabel);
    handleParameter(QLatin1String("use-ssl"), QVariant::Bool,
                    m_ui->sslCheckBox,
                    m_ui->sslLabel);
    handleParameter(QLatin1String("export-contacts"), QVariant::Bool,
                    m_ui->exportContactsCheckBox,
                    m_ui->exportContactsLabel);
}

SunshineAdvancedOptionsWidget::~SunshineAdvancedOptionsWidget()
{
    delete m_ui;
}

#include "sunshine-advanced-options-widget.moc"
